### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

#### [v0.1.0](https://github.com/Madghostek/zprp-ffmpeg/compare/v0.0.0...v0.1.0)

> 29 April 2024

- Mypy [`#2`](https://github.com/Madghostek/zprp-ffmpeg/pull/2)
- Ffmpeg connector and initial stream class logic [`#1`](https://github.com/Madghostek/zprp-ffmpeg/pull/1)
- feature: add very basic graph structure and crucial api parts [`cb6c4fd`](https://github.com/Madghostek/zprp-ffmpeg/commit/cb6c4fd2473b66f968131dfd806e82902395f78b)
- feature: crucial base classes for the package [`e133438`](https://github.com/Madghostek/zprp-ffmpeg/commit/e133438f08fbf248f28e7d67b4c40640ed9f3717)
- fix: remove not needed class, fix mypy type errors [`91aa8cf`](https://github.com/Madghostek/zprp-ffmpeg/commit/91aa8cf23ad051d4126083c57f6749bd49d4d517)

#### v0.0.0

> 26 March 2024

- Change authors [`2892f0f`](https://github.com/Madghostek/zprp-ffmpeg/commit/2892f0fac9b13743e06969e8e8a46ee8792541dd)
- Restore design proposal [`09e47f5`](https://github.com/Madghostek/zprp-ffmpeg/commit/09e47f5279fc933980b10e220292e400f2635b4e)
- Try to revert merge. [`6c4fda6`](https://github.com/Madghostek/zprp-ffmpeg/commit/6c4fda6d834687cc2a3e4e9cca4df722df1356aa)
